OC.L10N.register(
    "circles",
    {
    "Teams" : "Lantaldeak",
    "You created the team {circle}" : "{circle} lantaldea zuk sortu duzu",
    "{author} created the team {circle}" : "{author}(e)k {circle} lantaldea sortu du",
    "You deleted {circle}" : "{circle} ezabatu duzu",
    "{author} deleted {circle}" : "{author}(e)k {circle} ezabatu du",
    "You made {member} join {circle}" : "{member} kidea {circle}(e)n sartu duzu",
    "{author} made {member} join {circle}" : "{author}(e)k {circle} zirkuluan [member} kidea sartu du",
    "You added team {member} as member to {circle}" : "{member} lantaldea gehitu duzu kide gisa {circle}(e)ra",
    "{author} added team {member} as member to {circle}" : "{author} -k {member} lantaldea gehitu du {circle}-ko kide gisa.",
    "You made {member} leave {circle}" : "{member} kidea {circle}(e)tik atera duzu",
    "{author} made {member} leave {circle}" : "{author}(e)k {member} kidea {circle}(e)tik atera du",
    "You removed {member} from {circle}" : "{member} kidea atera duzu {circle} zirkulutik",
    "{author} removed {member} from {circle}" : "{author}-k {member}ezabatu du{circle}-tik",
    "You joined {circle}" : "{circle} zirkuluan sartu zara",
    "{member} joined {circle}" : "{member} kidea {circle} zirkuluan sartu da",
    "You accepted the invitation to join {circle}" : "{circle} zirkuluan sartzeko gonbidapena onartu duzu",
    "{member} accepted the invitation to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera onartu du",
    "You added {member} as member to {circle}" : "{member} gehitu duzu kide gisa {circle} zirkulura",
    "You have been added as member to {circle} by {author}" : "{circle} zirkulura gehitu zaitu {author}(e)k",
    "{member} has been added as member to {circle} by {author}" : "{member} kide gisa gehitu du {circle} zirkulura {author}(e)k",
    "You added {external} to {circle}" : "{external} gehitu duzu {circle}  zirkulura",
    "{external} has been added to {circle} by {author}" : "{external} gehitu du {circle} zirkulura {author}(e)k",
    "You accepted {member}'s request to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera onartu duzu",
    "Your request to join {circle} has been accepted by {author}" : "{circle} zirkuluan sartzeko zure eskaera onartu du {author}(e)k ",
    "{member}'s request to join {circle} has been accepted by {author}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera onartu du {author}(e)k",
    "You left {circle}" : "{circle} zirkulutik atera zara",
    "{member} left {circle}" : "{member} kidea {circle} zirkulutik atera da",
    "You declined the invitation to join {circle}" : " {circle} zirkuluan sartzeko gonbidapenari uko egin diozu",
    "{member} declined an invitation to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko gonbidapenari uko egin dio",
    "You cancelled your request to join {circle}" : "{circle} zirkuluan sartzeko eskaera bertan behera utzi duzu",
    "{member} cancelled a request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera bertan behera utzi du",
    "You have been removed from {circle} by {author}" : "{circle} zirkulutik atera zaitu {author}(e)k",
    "{member} has been removed from {circle} by {author}" : "{member} kidea atera du {circle} zirkulutik {author}(e)k",
    "You removed {external} from {circle}" : "{external} atera duzu {circle} zirkulutik",
    "{external} has been removed from {circle} by {author}" : "{external} atera du {circle} zirkulutik {author}(e)k",
    "You cancelled {member}'s invitation to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu duzu",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle} zirkuluan sartzeko zure eskaera baztertu egin du {author}(e)k",
    "{author} cancelled {member}'s invitation to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu du {author}(e)k",
    "You dismissed {member}'s request to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu duzu",
    "Your request to join {circle} has been dismissed by {author}" : "{circle} zirkuluan sartzeko zure eskaera baztertu egin du {author}(e)k ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu du {author}(e)k",
    "You invited {member} to join {circle}" : "{member} kidea {circle} zirkulura gonbidatu duzu",
    "You have been invited to join {circle} by {author}" : "{circle} zirkulura gonbidatu zaitu {author}(e)k",
    "{member} has been invited to join {circle} by {author}" : "{member} kidea gonbidatu du {circle} zirkulura {author}(e)k",
    "You changed {member}'s level in {circle} to %1$s" : "{circle} zirkuluan {member} kidearen maila aldatu duzu %1$s-ra",
    "{author} changed your level in {circle} to %1$s" : "{author}(e)k {circle} zirkuluan zure maila aldatu du %1$s-ra",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author}(e)k {circle} zirkuluan [member] kidearen maila aldatu du %1$s-ra",
    "You sent a request to join {circle}" : "{circle} zirkuluan sartzeko eskaera bidali duzu",
    "{member} sent a request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera egin du",
    "You are the new owner of {circle}" : "{circle} zirkuluaren jabe zara orain",
    "{member} is the new owner of {circle}" : "{member} kidea {circle} zirkuluaren jabe da orain",
    "On events happening in a <strong>team</strong> of which you are a member" : "Kide zaren <strong>lantalde</strong> bateko gertaeretan",
    "Any important event in a <strong>team</strong> you are moderating" : "Moderatzen ari zaren <strong>lantalde</strong> bateko edozein gertaera garrantzitsu",
    "On global events happening in any <strong>team</strong>" : "<strong>Lantalde</strong> batean gertatzen diren gertaera orokorretan",
    "Single" : "Bakana",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Visible" : "Ikusgai",
    "Open" : "Ireki",
    "Invite" : "Gonbidatu",
    "Join request" : "Sartzeko eskaera",
    "Friends" : "Lagunak",
    "Password protected" : "Pasahitz bidez babestuta",
    "No Owner" : "Jaberik ez",
    "Hidden" : "Ezkutuan",
    "Backend" : "Atzealdea",
    "Local" : "Lokala",
    "Root" : "Erroa",
    "Team invite" : "Lantalde-gonbidapena",
    "Federated" : "Federatua",
    "Mount point" : "Muntatze-puntua",
    "Nextcloud Account" : "Nextcloud kontua",
    "Nextcloud Group" : "Nextcloud taldea",
    "Email address" : "Helbide elektronikoa",
    "Contact" : "Kontaktua",
    "Team" : "Lantaldea",
    "Nextcloud App" : "Nextcloud aplikazioa",
    "Member" : "Kidea",
    "Moderator" : "Moderatzailea",
    "Admin" : "Administratzailea",
    "Owner" : "Jabea",
    "%s shared »%s« with you." : "%s(e)k »%s« partekatu du zurekin.",
    "%s shared »%s« with \"%s\"." : "%s(e)k »%s« partekatu du  \"%s\"-(r)ekin.",
    "%s on %s" : "%s hemen: %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k »%2$s« partekatu du zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s-k »%2$s« partekatu du zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s« atzitzeko pasahitza partekatu du zurekin %2$s(e)k",
    "Password to access »%s«" : "»%s« atzitzeko pasahitza",
    "It is protected with the following password:" : "Honako pasahitz honekin babestuta dago:",
    "%1$s via %2$s" : "%2$s bidez, %1$s",
    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko",
    "Open »%s«" : "Ireki »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s-k fitxategi batzuk partekatu ditu zurekin.\nHaietara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s-k fitxategi batzuk partekatu ditu zurekin. Haietara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access files shared to you by %1$s" : "Fitxategiak atzitzeko pasahitza partekatu du zurekin »%1$s«(e)k",
    "Password to access files" : "Fitxategiak atzitzeko pasahitza",
    "%s shared multiple files with \"%s\"." : "%s(e)k fitxategi batzuk partekatu ditu  \"%s\"-(r)ekin.",
    "%s shared multiple files with you." : "%s(e)k fitxategi batzuk partekatu ditu zurekin.",
    "Boot up" : "Abiarazi",
    "Nextcloud Initialization" : "Nextcloud hastapena",
    "Circles App Initialization" : "Zirkuluak aplikazioaren hastapena",
    "Fresh installation status" : "Instalazio berriaren egoera",
    "Building Local Database" : "Datu-base lokala eraikitzen",
    "Testing Basic Circle Creation" : "Oinarrizko zirkulu sorrera probatzen",
    "Adding local users and moderators" : "Erabiltzaile eta moderatzaile lokalak gehitzen",
    "Show all teams" : "Erakutsi lantalde guztiak",
    "Create a new team" : "Sortu lantalde berri bat",
    "Files" : "Fitxategiak",
    "This feature is not available for personal circles" : "Ezaugarri hau ez da existitzen zirkulu pertsonaletarako",
    "The team is not federated" : "Lantaldea ez dago federatuta",
    "You cannot join this team" : "Ezin zara lantalde honetara sartu",
    "This member is not a moderator" : "Kide hau ez da moderatzailea",
    "Insufficient privileges" : "Baimen gutxiegi",
    "This member does not exist" : "Kide hau ez da existitzen",
    "This member is the owner of the team" : "Kide hau lantaldearen jabea da",
    "Level cannot be changed for this type of member" : "Ezin da mota honetako kideen maila aldatu",
    "You are already a member of this circle" : "Zirkulu honetako kide zara dagoeneko",
    "You have been blocked from this circle" : "Zirkulu honetan blokeatu egin zaituzte",
    "The account is already a member of this circle" : "Kontu hau zirkulu honetako kidea da dagoeneko",
    "The account has already been invited into this circle" : "Kontua zirkulu honetara gonbidatua izan da dagoeneko",
    "%s (Team owned by %s)" : "%s (%s-(r)en jabetzako lantaldea)",
    "You are now a member of the Team \"%2$s\"" : "«%2$s» lantaldearen kide zara orain",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s(e)k «%2$s» lantaldera gonbidatu zaitu",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s(e)k «%2$s» lantaldearen kide izateko eskaera bidali du",
    "Accept" : "Onartu",
    "Refuse" : "Ukatu",
    "Leave the team" : "Utzi lantaldea",
    "%s" : "%s",
    "Personal team" : "Lantalde pertsonala",
    "%s owned by %s" : "%s jabea: %s",
    "You have no permission to create a new team" : "Ez duzu lantalde berri bat sortzeko baimenik",
    "%s shared a file with \"%s\"." : "%s fitxategi bat partekatu du \"%s\"(r)ekin.",
    "%s shared a file with you." : "%s zurekin fitxategi bat partekatu du.",
    "%1$s shared %2$s with %3$s" : "%1$s-k  %2$s partekatu du %3$s-rekin",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s-k %2$s partekatu du \"%3$s\"-rekin",
    "Open %s" : "Ireki %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k eduki batzuk partekatu ditu zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s(e)k eduki batzuk partekatu ditu zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access content shared with you by %1$s" : "%1$s-k zurekin partekatutako edukiera atzitzeko pasahitza",
    "Password to access content" : "Edukia atzitzeko pasahitza",
    "This item is already shared with this team" : "Elementu hau dagoeneko partekatu da lantalde honekin",
    "Bring cloud-users closer together." : "Elkartu gehiago hodei erabiltzaileak.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Lantaldeak jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin.",
    "Failed to load teams" : "Lantaldeak kargatzeak huts egin du",
    "Try again" : "Saiatu berriz",
    "No teams found" : "Ez da lantalderik aurkitu",
    "Join or create teams to see them here." : "Elkartu edo lantaldeak sortu, hemen ikusteko.",
    "Create your first team" : "Sortu zure lehenengo lantaldea",
    "Loading…" : "Kargatzen…",
    "More teams" : "Lantalde gehiago",
    "No files in here" : "Ez dago fitxategirik hemen",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan ",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatua",
    "Teams' files" : "Lantaldeen fitxategiak",
    "Select team to filter by" : "Hautatu iragazteko lantaldea",
    "Please select teams to filter by" : "Hautatu lantaldeak iragazteko",
    "No files found for the selected teams" : "Ez da fitxategirik aurkitu hautatutako lantaldeetarako",
    "Shared to Circles" : "Zirkuluetara partekatua",
    "Circle" : "Zirkulua"
},
"nplurals=2; plural=(n != 1);");
